Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintBooleanConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb

Overview

A constraint type is enforced or not enforced, which is configured in the PolicyRule. If customConstraintDefinition is defined, this constraint is a managed constraint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ConstraintBooleanConstraint

Returns a new instance of GoogleCloudOrgpolicyV2ConstraintBooleanConstraint.



153
154
155
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_constraint_definitionGoogle::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinition

Custom constraint definition. Defines this as a managed constraint. Corresponds to the JSON property customConstraintDefinition



151
152
153
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 151

def custom_constraint_definition
  @custom_constraint_definition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



158
159
160
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 158

def update!(**args)
  @custom_constraint_definition = args[:custom_constraint_definition] if args.key?(:custom_constraint_definition)
end