Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2CustomConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb

Overview

A custom constraint defined by customers which can only be applied to the given resource types and organization. By creating a custom constraint, customers can apply policies of this custom constraint. Creating a custom constraint itself does NOT apply any policy enforcement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOrgpolicyV2CustomConstraint

Returns a new instance of GoogleCloudOrgpolicyV2CustomConstraint.



370
371
372
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_typeString

Allow or deny type. Corresponds to the JSON property actionType

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 320

def action_type
  @action_type
end

#conditionString

A Common Expression Language (CEL) condition which is used in the evaluation of the constraint. For example: resource.instanceName.matches("(production| test)_(.+_)?[\d]+") or, resource.management.auto_upgrade == true The max length of the condition is 1000 characters. Corresponds to the JSON property condition

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 328

def condition
  @condition
end

#descriptionString

Detailed information about this custom policy constraint. The max length of the description is 2000 characters. Corresponds to the JSON property description

Returns:

  • (String)


334
335
336
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 334

def description
  @description
end

#display_nameString

One line display name for the UI. The max length of the display_name is 200 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 340

def display_name
  @display_name
end

#method_typesArray<String>

All the operations being applied for this constraint. Corresponds to the JSON property methodTypes

Returns:

  • (Array<String>)


345
346
347
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 345

def method_types
  @method_types
end

#nameString

Immutable. Name of the constraint. This is unique within the organization. The name must be of the form: * organizations/organization_id/customConstraints/ custom_constraint_id`Example:organizations/123/customConstraints/custom. createOnlyE2TypeVms` The max length is 71 characters and the minimum length is

  1. Note that the prefix organizations/organization_id/customConstraints/ custom. is not counted. Corresponds to the JSON property name

Returns:

  • (String)


355
356
357
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 355

def name
  @name
end

#resource_typesArray<String>

Immutable. The resource instance type on which this policy applies. Format will be of the form : / Example: * compute.googleapis.com/Instance. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


361
362
363
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 361

def resource_types
  @resource_types
end

#update_timeString

Output only. The last time this custom constraint was updated. This represents the last time that the CreateCustomConstraint or UpdateCustomConstraint methods were called. Corresponds to the JSON property updateTime

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 368

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



375
376
377
378
379
380
381
382
383
384
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 375

def update!(**args)
  @action_type = args[:action_type] if args.key?(:action_type)
  @condition = args[:condition] if args.key?(:condition)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @method_types = args[:method_types] if args.key?(:method_types)
  @name = args[:name] if args.key?(:name)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
  @update_time = args[:update_time] if args.key?(:update_time)
end