Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues
- Inherits:
-
Object
- Object
- Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb
Overview
A message that holds specific allowed and denied values. This message can
define specific values and subtrees of the Resource Manager resource hierarchy
(Organizations, Folders, Projects) that are allowed or denied. This is
achieved by using the under: and optional is: prefixes. The under:
prefix is used to denote resource subtree values. The is: prefix is used to
denote specific values, and is required only if the value contains a ":".
Values prefixed with "is:" are treated the same as values with no prefix.
Ancestry subtrees must be in one of the following formats: - projects/ (for
example, projects/tokyo-rain-123) - folders/ (for example, folders/1234)
organizations/(for example,organizations/1234) Thesupports_underfield of the associatedConstraintdefines whether ancestry prefixes can be used.
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
List of values allowed at this resource.
-
#denied_values ⇒ Array<String>
List of values denied at this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues
constructor
A new instance of GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues
Returns a new instance of GoogleCloudOrgpolicyV2PolicySpecPolicyRuleStringValues.
697 698 699 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_values ⇒ Array<String>
List of values allowed at this resource.
Corresponds to the JSON property allowedValues
690 691 692 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 690 def allowed_values @allowed_values end |
#denied_values ⇒ Array<String>
List of values denied at this resource.
Corresponds to the JSON property deniedValues
695 696 697 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 695 def denied_values @denied_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
702 703 704 705 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 702 def update!(**args) @allowed_values = args[:allowed_values] if args.key?(:allowed_values) @denied_values = args[:denied_values] if args.key?(:denied_values) end |