Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter
- Inherits:
-
Object
- Object
- Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb
Overview
Defines a parameter structure.
Instance Attribute Summary collapse
-
#default_value ⇒ Object
Sets the value of the parameter in an assignment if no value is given.
-
#item ⇒ String
Determines the parameter's value structure.
-
#metadata ⇒ Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameterMetadata
Defines Metadata structure.
-
#type ⇒ String
Type of the parameter.
-
#valid_values_expr ⇒ String
Provides a CEL expression to specify the acceptable parameter values during assignment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter
constructor
A new instance of GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter
Returns a new instance of GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameter.
242 243 244 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 242 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Object
Sets the value of the parameter in an assignment if no value is given.
Corresponds to the JSON property defaultValue
217 218 219 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 217 def default_value @default_value end |
#item ⇒ String
Determines the parameter's value structure. For example, LIST can be
specified by defining type: LIST, and item: STRING.
Corresponds to the JSON property item
223 224 225 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 223 def item @item end |
#metadata ⇒ Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ConstraintCustomConstraintDefinitionParameterMetadata
Defines Metadata structure.
Corresponds to the JSON property metadata
228 229 230 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 228 def @metadata end |
#type ⇒ String
Type of the parameter.
Corresponds to the JSON property type
233 234 235 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 233 def type @type end |
#valid_values_expr ⇒ String
Provides a CEL expression to specify the acceptable parameter values during
assignment. For example, parameterName in ("parameterValue1", "parameterValue2"
)
Corresponds to the JSON property validValuesExpr
240 241 242 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 240 def valid_values_expr @valid_values_expr end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
247 248 249 250 251 252 253 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 247 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @item = args[:item] if args.key?(:item) @metadata = args[:metadata] if args.key?(:metadata) @type = args[:type] if args.key?(:type) @valid_values_expr = args[:valid_values_expr] if args.key?(:valid_values_expr) end |