Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ListCustomConstraintsResponse
- Inherits:
-
Object
- Object
- Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ListCustomConstraintsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb
Overview
The response returned from the ListCustomConstraints method. It will be empty if no custom or managed constraints are set on the organization resource.
Instance Attribute Summary collapse
-
#custom_constraints ⇒ Array<Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2CustomConstraint>
All custom and managed constraints that exist on the organization resource.
-
#next_page_token ⇒ String
Page token used to retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ListCustomConstraintsResponse
constructor
A new instance of GoogleCloudOrgpolicyV2ListCustomConstraintsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ListCustomConstraintsResponse
Returns a new instance of GoogleCloudOrgpolicyV2ListCustomConstraintsResponse.
429 430 431 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_constraints ⇒ Array<Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2CustomConstraint>
All custom and managed constraints that exist on the organization resource. It
will be empty if no custom constraints are set.
Corresponds to the JSON property customConstraints
421 422 423 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 421 def custom_constraints @custom_constraints end |
#next_page_token ⇒ String
Page token used to retrieve the next page. This is not used, but the server
may at any point start supplying a valid token.
Corresponds to the JSON property nextPageToken
427 428 429 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 427 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
434 435 436 437 |
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 434 def update!(**args) @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |