Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2ListCustomConstraintsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb

Overview

The response returned from the ListCustomConstraints method. It will be empty if no custom or managed constraints are set on the organization resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOrgpolicyV2ListCustomConstraintsResponse

Returns a new instance of GoogleCloudOrgpolicyV2ListCustomConstraintsResponse.



426
427
428
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_constraintsArray<Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2CustomConstraint>

All custom and managed constraints that exist on the organization resource. It will be empty if no custom constraints are set. Corresponds to the JSON property customConstraints



418
419
420
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 418

def custom_constraints
  @custom_constraints
end

#next_page_tokenString

Page token used to retrieve the next page. This is currently not used, but the server may at any point start supplying a valid token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


424
425
426
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 424

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



431
432
433
434
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 431

def update!(**args)
  @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end