Class: Google::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/orgpolicy_v2/classes.rb,
lib/google/apis/orgpolicy_v2/representations.rb,
lib/google/apis/orgpolicy_v2/representations.rb

Overview

Defines an organization policy which is used to specify constraints for configurations of Google Cloud resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOrgpolicyV2Policy

Returns a new instance of GoogleCloudOrgpolicyV2Policy.



508
509
510
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternateGoogle::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2AlternatePolicySpec

Similar to PolicySpec but with an extra 'launch' field for launch reference. The PolicySpec here is specific for dry-run. Corresponds to the JSON property alternate



474
475
476
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 474

def alternate
  @alternate
end

#dry_run_specGoogle::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2PolicySpec

Defines a Google Cloud policy specification which is used to specify constraints for configurations of Google Cloud resources. Corresponds to the JSON property dryRunSpec



480
481
482
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 480

def dry_run_spec
  @dry_run_spec
end

#etagString

Optional. An opaque tag indicating the current state of the policy, used for concurrency control. This 'etag' is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 488

def etag
  @etag
end

#nameString

Immutable. The resource name of the policy. Must be one of the following forms, where constraint_name is the name of the constraint which this policy configures: * projects/project_number/policies/constraint_name* ` folders/`folder_id`/policies/`constraint_name * organizations/ organization_id/policies/constraint_nameFor example, `projects/123/ policies/compute.disableSerialPortAccess`. Note: `projects/`project_id`/ policies/`constraint_name is also an acceptable name for API requests, but responses will return the name using the equivalent project number. Corresponds to the JSON property name

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 500

def name
  @name
end

#specGoogle::Apis::OrgpolicyV2::GoogleCloudOrgpolicyV2PolicySpec

Defines a Google Cloud policy specification which is used to specify constraints for configurations of Google Cloud resources. Corresponds to the JSON property spec



506
507
508
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 506

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



513
514
515
516
517
518
519
# File 'lib/google/apis/orgpolicy_v2/classes.rb', line 513

def update!(**args)
  @alternate = args[:alternate] if args.key?(:alternate)
  @dry_run_spec = args[:dry_run_spec] if args.key?(:dry_run_spec)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
end